@@ -1,5 +1,5 @@
 package Text::Hogan;
-$Text::Hogan::VERSION = '0.06';
+$Text::Hogan::VERSION = '0.07';
 use strict;
 use warnings;
 
@@ -9,11 +9,11 @@ __END__
 
 =head1 NAME
 
-Text::Hogan -A mustache templating engine statement-for-statement cloned from hogan.js
+Text::Hogan - A mustache templating engine statement-for-statement cloned from hogan.js
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -26,13 +26,15 @@ version 0.06
 
     say $template->render({ name => "Alex" });
 
+See Text::Hogan::Compiler and Text::Hogan::Template for more details.
+
 =head1 COPYRIGHT
 
 Copyright (C) 2015 Lokku Ltd.
 
 =head1 AUTHOR
 
-Basically statement-for-statement copied from hogan.js by Twitter!
+Statement-for-statement copied from hogan.js by Twitter!
 
 Alex Balhatchet (alex@lokku.com)
 
